/* ============================================================================
 * Project Name: DDS24_sweep_sw_P4
 *
 * Description:
 *   Demo project demonstrating use of DDS24 component for generation of
 *   tunable frequency using API calls for updating DDS parameters
 *   (software timing) 
 * 
 * Uses:
 *   DDS24: 24-bit DDS frequency generator component (v 0.1)
 *
 * ============================================================================
 * PROVIDED AS-IS, NO WARRANTY OF ANY KIND, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 * FREE TO SHARE, USE AND MODIFY UNDER TERMS: CREATIVE COMMONS - SHARE ALIKE
 * ============================================================================
*/



#include <project.h>


static volatile CYBIT flag_Timer = 0 ; //semaphore   
CY_ISR(isr_Timer) // ISR Timer to update frequency at regular interval
{
    flag_Timer = 1;
}

//===========================================
// Function prototypes
//===========================================
void UpdateDDSfrequency();



//===========================================
// Global variables
//===========================================

    double FStart = 1000.0f;        // start frequency
    double FStep  = 100.0f;         // frequency increment step  
    uint16 NSteps = 255u;           // number of increment steps (FStop=FStart + FStep * NSteps); Npoints = NSteps + 1   
    

void Initialize()
{   
    CyGlobalIntEnable;              //enable global interrupts.
    isr_Timer_StartEx(isr_Timer);   //start DDS update timer

    DDS_1_Start();                  // initialise and enable
}


int main()
{
    Initialize();
 
    //for(;;){} //test fized frequency 
    
    
    for(;;) //forever
    {
         
       
        if (flag_Timer)             // update frequency on interrupt 
    	{    
            flag_Timer = 0;         
            UpdateDDSfrequency();   
        }
           
    } 
    
} // main()



//==============================================================================
// Set new DDS frequency 
//==============================================================================

void UpdateDDSfrequency()
{
    static int16 counter = -1;  //use static to keep  recorded value
    static int16 increment = 0; //use static to keep  recorded value
    double Freq;                //
    
     
    //move phase back-forward between 0 and NSteps 
    if (counter >= NSteps) increment = -1; else //go backwards
    if (counter <= 0) increment = 1;            //go forward
        
    counter += increment;
    Freq = FStart + FStep * counter;
    
    DDS_1_SetFrequency(Freq);   //Upload next frequency value into DDS buffer     
}


